extends Node2D

onready var line = $Line2D
onready var icon = $Icon

var timer = 0
var curve = Curve2D.new()

func _reset_curve():
	curve.clear_points()
	
	# 制御点 (方向ベクトル) を求める
	var c0 = $P1.position - $P0.position # 始点の制御点
	var c1 = $P3.position - $P2.position # 終点の制御点
	
	curve.bake_interval = 2.0 # 分割距離 (小さいほど細かくなる)
	
	# 始点と制御点を設定 (outに制御点を指定する)
	curve.add_point($P0.position, Vector2.ZERO, c0)
	# 終点と制御点を設定 (inに制御点を指定する)
	curve.add_point($P2.position, c1, Vector2.ZERO)

	line.clear_points()
	for p in curve.get_baked_points():
		line.add_point(p)
		print(p)
	
func _ready():
	_reset_curve()


func _process(delta):
	
	timer += delta
	var max_points = curve.get_baked_points().size()
	# 3.0秒で終端に移動するようにする
	var rate = timer / 3.0
	if rate < 1.0:
		var idx = (max_points * rate)
		icon.position = curve.get_baked_points()[idx]
	
	
	if Input.is_action_just_pressed("ui_accept"):
		# 始点と終点をランダムな場所に移動する
		#$P0.position.x = rand_range(128, 1024-128)
		#$P0.position.y = rand_range(128, 600-128)
		#$P2.position.x = rand_range(128, 1024-128)
		#$P2.position.y = rand_range(128, 600-128)
		
		# 制御点をランダムな場所に移動する
		$P1.position.x = rand_range(128, 1024-128)
		$P1.position.y = rand_range(128, 600-128)
		$P3.position.x = rand_range(128, 1024-128)
		$P3.position.y = rand_range(128, 600-128)
		
		# カーブを作り直す
		_reset_curve()
		
		timer = 0
	
	# 描画更新
	update()
	
func _draw():
	# Draw the handles
	# 始点と終点
	draw_circle($P0.position,5.0,Color.blue)
	draw_circle($P2.position,5.0,Color.red)
	# 制御点
	draw_circle($P1.position,5.0,Color.green)
	draw_circle($P3.position,5.0,Color.green)
	
	
	draw_line($P0.position, $P1.position, Color.silver)
	draw_line($P2.position, $P3.position, Color.silver)
